@@ -1,7 +1,7 @@
 """All type annotations go here."""
+from __future__ import annotations
 
-
-from typing import TYPE_CHECKING, Any, Union
+from typing import TYPE_CHECKING, Any, Callable, Union
 
 if TYPE_CHECKING:
     from asyncio import AbstractEventLoop
@@ -11,7 +11,9 @@ if TYPE_CHECKING:
     from aio_wx_widgets.controller import BaseController
     from aio_wx_widgets.core.base_widget import BaseWidget, CallableItem
     from aio_wx_widgets.core.binding import Binding
+    from aio_wx_widgets.core.sizers import PanelMixin
 
+    assert PanelMixin
     try:
         import Protocol  # type: ignore
     except ImportError:
@@ -30,3 +32,4 @@ if TYPE_CHECKING:
         value: Any
 
     Widget = Union[BaseWidget, wx.Window, wx.BoxSizer, CallableItem]
+    ConverterType = Callable[[Any], Union[float, int, str, bool]]
