@@ -21,6 +21,11 @@ def _get_font_info(current_font: wx.Font, font_size: float = 1, bold=False) -> w
     if font_size != 1:
         current_font_size = current_font.GetPointSize()
         new_font_size = int(font_size * current_font_size)
+        _LOGGER.debug(
+            "Debug ratio of %s results in absolute font size of %s",
+            font_size,
+            new_font_size,
+        )
         font.SetPointSize(new_font_size)
 
     if bold:
@@ -32,22 +37,27 @@ def _get_font_info(current_font: wx.Font, font_size: float = 1, bold=False) -> w
 class Text(BaseWidget):
     """Static text."""
 
+    HOR_CENTER = wx.ALIGN_CENTRE_HORIZONTAL
+    HOR_RIGHT = wx.ALIGN_RIGHT
+    HOR_LEFT = wx.ALIGN_LEFT
+
     def __init__(
         self,
         text="",
         font_size: float = 1,
-        color: Optional[int] = None,
+        color: Union[int, Binding, None] = None,
         enabled: Union[bool, Binding] = True,
         binding: Optional[Binding] = None,
         bold=False,
         wrap=False,
         min_width=-1,
+        hor_align: Optional[int] = None,
     ):
         """Init.
 
         Args:
             text:
-            font_size:
+            font_size: Font size ratio.
         """
         value_binding = (
             OneWayBindable(binding, self._set_ui_value) if binding is not None else None
@@ -65,56 +75,77 @@ class Text(BaseWidget):
         self._wrap = wrap
 
         self._font = _get_font_info(self.ui_item.GetFont(), font_size, bold=bold)
-
-        self._previous_size = None
+        self._color_binding = None
+        self._previous_size = (0, 0)
+        self._hor_align = hor_align
 
     def _set_ui_value(self, value):
         self.set_text(value)
 
-    def __call__(self, parent):
+    def _get_style(self) -> int:
+        style = 0
+
+        if self._hor_align:
+            style = style | self._hor_align
+
+        return style
+
+    def init(self, parent):
+
         self._parent = parent
-        self.ui_item.Create(parent)
+        self._parent.Bind(wx.EVT_SIZE, self._on_parent_size)
+
+        self.ui_item.Create(parent, style=self._get_style())
 
         if self._font:
             self.ui_item.SetFont(self._font)
 
-        if self._text:
-            self.set_text(self._text, self._color)
-        if self._value_binding:
-            self.set_text(self._value_binding.get_property_value(), self._color)
         if is_debugging():
             self.ui_item.SetBackgroundColour(GREEN)
         self._init()
-        self.ui_item.Bind(wx.EVT_SIZE, self._on_size)
+        self._parent.PostSizeEvent()
 
+    def __call__(self, parent):
+        self.init(parent)
         return self
 
+    def _on_parent_size(self, evt):
+        container = self.ui_item.ContainingSizer
+        _LOGGER.debug(container.Size)
+
+        if container.Size[0] == 0:
+            _LOGGER.debug("Not setting text.")
+        elif self._previous_size[0] == container.Size[0]:
+            _LOGGER.debug("Previous size is the same skipping.")
+        else:
+            self._previous_size = container.Size
+            smaller_size = (self.ui_item.Size[0], -1)
+            self._set_text(client_size=smaller_size)
+            self.ui_item.Parent.Refresh()
+
+        evt.Skip()
+
     def _set_text(self, color=None, client_size=None):
-        # _LOGGER.debug("Setting text to: %s", self._text)
-        self.ui_item.Unbind(wx.EVT_SIZE)
 
         self.ui_item.SetLabel(str(self._text))
-
         if self._wrap:
             if client_size:
                 self.ui_item.Wrap(client_size[0])
 
-        if color:
-            self.ui_item.SetForegroundColour(color)
-
-        self.ui_item.Bind(wx.EVT_SIZE, self._on_size)
-
-    def _on_size(self, evt):
-        size = evt.Size
-        if self._previous_size is not None and self._previous_size[0] == size[0]:
-            return
-
-        self._previous_size = size
-        self._set_text(client_size=size)
-
-        # evt.Skip()
-
     def set_text(self, text, color=None):
         """Set or change the text."""
         self._text = str(text)
         self._set_text(color)
+
+    def _set_color(self, color):
+        """Set text color when color binding changes."""
+        _LOGGER.debug("Setting color to : %s", color)
+
+        self.ui_item.SetForegroundColour(color)
+        self._parent.Refresh()
+
+    def _make_bindings(self):
+        if self._color is not None and isinstance(self._color, Binding):
+            self._color_binding = OneWayBindable(self._color, self._set_color)
+            self._color_binding.make_binding()
+        super()._make_bindings()
